#ifndef MINER_OWNED_STATES_H
#define MINER_OWNED_STATES_H
//------------------------------------------------------------------------
//
//  Name:   MinerOwnedStates.h
//
//  Desc:   All the states that can be assigned to the Miner class
//
//  Author: Mat Buckland 2002 (fup@ai-junkie.com)
//
//------------------------------------------------------------------------
#include "State.h"
#include <rcsc/player/player_agent.h>


class Miner;

class AdvanceBall : public State
{
private:

  AdvanceBall(){}

   AdvanceBall(const AdvanceBall&);
  AdvanceBall& operator=(const AdvanceBall&);

public:

  //this is a singleton
  static AdvanceBall* Instance();
  
  virtual void Enter(Miner* miner);

  virtual void Execute(Miner* miner);

  virtual void Exit(Miner* miner);
};

//------------------------------------------------------------------------
//
//  Entity will go to a bank and deposit any nuggets he is carrying. If the 
//  miner is subsequently wealthy enough he'll walk home, otherwise he'll
//  keep going to get more gold
//------------------------------------------------------------------------
class NormalPass : public State
{
private:

  NormalPass(){}

  //copy ctor and assignment should be private
  NormalPass(const NormalPass&);
  NormalPass& operator=(const NormalPass&);
  
public:

  //this is a singleton
  static NormalPass* Instance();

  virtual void Enter(Miner* miner);

  virtual void Execute(Miner* miner);

  virtual void Exit(Miner* miner);
};


//------------------------------------------------------------------------
//
//  miner will go home and sleep until his fatigue is decreased
//  sufficiently
//------------------------------------------------------------------------
class SafePass : public State
{
private:

  SafePass(){}

    //copy ctor and assignment should be private
  SafePass(const SafePass&);
  SafePass& operator=(const SafePass&);

public:

  //this is a singleton
  static SafePass* Instance();

  virtual void Enter(Miner* miner);

  virtual void Execute(Miner* miner);

  virtual void Exit(Miner* miner);
};




//------------------------------------------------------------------------
//
//------------------------------------------------------------------------
class Drible : public State
{
private:
  
  Drible(){}

  //copy ctor and assignment should be private
  Drible(const Drible&);
  Drible& operator=(const Drible&);

public:

  //this is a singleton
  static Drible* Instance();

  virtual void Enter(Miner* miner);

  virtual void Execute(Miner* miner );

  virtual void Exit(Miner* miner);
};

//------------------------------------------------------------------------
//
//  miner will go home and sleep until his fatigue is decreased
//  sufficiently
//------------------------------------------------------------------------
class StateBegin : public State
{
private:

  StateBegin(){}

    //copy ctor and assignment should be private
  StateBegin(const StateBegin&);
  StateBegin& operator=(const StateBegin&);

public:

  //this is a singleton
  static StateBegin* Instance();

  virtual void Enter(Miner* miner);

  virtual void Execute(Miner* miner);

  virtual void Exit(Miner* miner);
};






#endif